@@ -287,8 +287,8 @@ class TradingBroker(BaseBroker):
             if data_exchange == DataExchange.NXT and price_data.get("open_price", 0) == 0:  # current_price는 어제의 값을 반환하므로 open_price가 0인지로 NXT 시장 여부 확인
                 price_data = self.data_api.get_price(code, data_exchange=DataExchange.KRX)
         else:
-            if self.market_nxt_on:  # TODO: 정규장에서도 NXT 가격을 우선 조회하는 것이니 수정 필요
-                price_data = self.data_api.get_price(code, data_exchange=DataExchange.NXT)
+            if self.market_nxt_on:
+                price_data = self.data_api.get_price(code, data_exchange=DataExchange.UN)
                 if price_data.get("open_price", 0) == 0:  # current_price는 어제의 값을 반환하므로 open_price가 0인지로 NXT 시장 여부 확인
                     price_data = self.data_api.get_price(code, data_exchange=DataExchange.KRX)
             else:
@@ -306,7 +306,7 @@ class TradingBroker(BaseBroker):
                 result = self.data_api.get_today_minute_data(code, data_exchange=DataExchange.KRX)
         else:
             if self.market_nxt_on:
-                result = self.data_api.get_today_minute_data(code, data_exchange=DataExchange.NXT)
+                result = self.data_api.get_today_minute_data(code, data_exchange=DataExchange.UN)
                 if result.empty or result.iloc[-1].close == 0:
                     result = self.data_api.get_today_minute_data(code, data_exchange=DataExchange.KRX)
             else:
@@ -316,12 +316,12 @@ class TradingBroker(BaseBroker):
     def get_daily_price(self, code: str, from_date: dtm.date, to_date: dtm.date, data_exchange: Optional[DataExchange] = None) -> pd.DataFrame:
         if data_exchange:
             result = self.data_api.get_historical_daily_data(code, from_date, to_date, adjusted_price=True, data_exchange=data_exchange)
-            if data_exchange == DataExchange.NXT and result.empty:
+            if data_exchange == DataExchange.NXT and (result.empty or result.iloc[0].open == 0):
                 result = self.data_api.get_historical_daily_data(code, from_date, to_date, adjusted_price=True, data_exchange=DataExchange.KRX)
         else:
             if self.market_nxt_on:
-                result = self.data_api.get_historical_daily_data(code, from_date, to_date, adjusted_price=True, data_exchange=DataExchange.NXT)
-                if result.empty:
+                result = self.data_api.get_historical_daily_data(code, from_date, to_date, adjusted_price=True, data_exchange=DataExchange.UN)
+                if result.empty or result.iloc[0].open == 0:
                     result = self.data_api.get_historical_daily_data(code, from_date, to_date, adjusted_price=True, data_exchange=DataExchange.KRX)
             else:
                 result = self.data_api.get_historical_daily_data(code, from_date, to_date, adjusted_price=True, data_exchange=DataExchange.KRX)
@@ -576,7 +576,12 @@ class MockBroker(BaseBroker):
         market_schedule = get_market_schedule(today, exchange=self._get_exchange_code())
         open_time = market_schedule.open_time
         if self.market_nxt_on:
-            open_time = dtm.time(8, 0, 0)
+            try:
+                nxt_market_schedule = get_market_schedule(today, exchange="NXT")
+                open_time = nxt_market_schedule.open_time
+            except ValueError:
+                # 2025-03-04 이전 날짜는 ValueError 이므로 무시
+                pass
 
         if now.time() < open_time:
             last_trading_day = get_last_trading_day(today, exchange=self._get_exchange_code())
@@ -603,7 +608,7 @@ class MockBroker(BaseBroker):
 
     def get_minute_price(self, code: str) -> pd.DataFrame:
         """
-        self.clock 기준 당일의 정규장 시작부터 현재 시각 (이전) 까지의 분봉 데이터를 조회합니다.  
+        self.clock 기준 당일의 정규장 시작부터 현재 시각 (이전) 까지의 분봉 데이터를 조회합니다.
         단, market_nxt_on 이면, NXT 가능 종목의 경우 프리마켓, 정규마켓, 애프터마켓의 분봉을 모두 조회합니다.
 
         Args:
@@ -623,10 +628,15 @@ class MockBroker(BaseBroker):
         close_time = dtm.datetime.combine(today, market_schedule.close_time)
 
         # TODO: us_stock 에 대해서는 따로 적용해야 함.
-        is_nxt = df.index[0] == dtm.datetime.combine(today, dtm.time(8, 0, 0))
-        if self.market_nxt_on and is_nxt:
-            open_time = dtm.datetime.combine(today, dtm.time(8, 0, 0))
-            close_time = dtm.datetime.combine(today, dtm.time(20, 0, 0))
+        try:
+            nxt_market_schedule = get_market_schedule(today, "NXT")
+            is_nxt = df.index[0] == dtm.datetime.combine(today, nxt_market_schedule.open_time)
+            if self.market_nxt_on and is_nxt:
+                open_time = dtm.datetime.combine(today, nxt_market_schedule.open_time)
+                close_time = dtm.datetime.combine(today, nxt_market_schedule.close_time)
+        except ValueError:
+            # 2025-03-04 이전 날짜는 ValueError 이므로 무시
+            pass
 
         if df.index.tz is not None:
             df.index = df.index.tz_localize(None)
@@ -707,9 +717,40 @@ class MockBroker(BaseBroker):
             dfs = get_us_minute_data(date, [code])
         else:
             if self.market_nxt_on:
-                dfs = get_kr_minute_data(date, [code], dtm.timedelta(minutes=1), source="kis", adjusted=True, exchange=DataExchange.NXT)
-                if dfs[code].empty:  # NXT 에 해당 종목이 없는 경우 KRX 의 결과값을 반환한다. 하지만 로컬 캐시 폴더는 NXT 기준으로 저장한다.
-                    dfs = get_kr_minute_data(date, [code], dtm.timedelta(minutes=1), source="kis", adjusted=True, exchange=DataExchange.KRX)
+                # NXT 에 해당 종목이 없는 경우 KRX 의 결과값을 반환한다. 하지만 로컬 캐시 폴더는 NXT 기준으로 저장한다.
+                dfs = get_kr_minute_data(date, [code], dtm.timedelta(minutes=1), source="kis", adjusted=True, exchange=DataExchange.KRX)
+                dfs_nxt = get_kr_minute_data(date, [code], dtm.timedelta(minutes=1), source="kis", adjusted=True, exchange=DataExchange.NXT)
+                if code in dfs_nxt and not dfs_nxt[code].empty:
+                    _df = dfs[code]
+                    _df_nxt = dfs_nxt[code]
+                    common_dates = _df.index.intersection(_df_nxt.index)
+                    for _date in common_dates:
+                        _df_nxt.loc[_date, 'volume'] = _df.loc[_date, 'volume'] + _df_nxt.loc[_date, 'volume']
+                        _df_nxt.loc[_date, 'value'] = _df.loc[_date, 'value'] + _df_nxt.loc[_date, 'value']
+                        _df_nxt.loc[_date, 'cum_volume'] = _df.loc[_date, 'cum_volume'] + _df_nxt.loc[_date, 'cum_volume']
+                        _df_nxt.loc[_date, 'cum_value'] = _df.loc[_date, 'cum_value'] + _df_nxt.loc[_date, 'cum_value']
+                        # 한투 앱에서 통합 차트의 경우 KRX값이 우선으로 사용됨
+                        _df_nxt.loc[_date, 'open'] = _df.loc[_date, 'open']
+                        _df_nxt.loc[_date, 'high'] = max(_df.loc[_date, 'high'], _df_nxt.loc[_date, 'high'])
+                        _df_nxt.loc[_date, 'low'] = min(_df.loc[_date, 'low'], _df_nxt.loc[_date, 'low'])
+                        _df_nxt.loc[_date, 'close'] = _df.loc[_date, 'close']
+
+                    # 15:30 이후의 cum_volume, cum_value는 15:30의 cum_volume, cum_value에다가 _df_nxt의 15:31 부터 각 volume, value를 매분 누적하여 저장
+                    market_close_datetime = dtm.datetime.combine(date, get_market_schedule(date, "KRX").close_time)
+                    if market_close_datetime in _df_nxt.index:
+                        base_cum_volume = _df_nxt.loc[market_close_datetime, 'cum_volume']
+                        base_cum_value = _df_nxt.loc[market_close_datetime, 'cum_value']
+
+                        # 15:31 이후 데이터에 대해 누적 계산
+                        after_market_close = _df_nxt.index > market_close_datetime
+                        if after_market_close.any():
+                            for idx in _df_nxt[after_market_close].index:
+                                _df_nxt.loc[idx, 'cum_volume'] = base_cum_volume + _df_nxt.loc[idx, 'volume']
+                                _df_nxt.loc[idx, 'cum_value'] = base_cum_value + _df_nxt.loc[idx, 'value']
+                                base_cum_volume = _df_nxt.loc[idx, 'cum_volume']
+                                base_cum_value = _df_nxt.loc[idx, 'cum_value']
+
+                    dfs[code] = _df_nxt
             else:
                 dfs = get_kr_minute_data(date, [code], dtm.timedelta(minutes=1), source="kis", adjusted=True, exchange=DataExchange.KRX)
 
@@ -736,7 +777,7 @@ class MockBroker(BaseBroker):
 
     def get_daily_price(self, code: str, from_date: Optional[dtm.date] = None, end_date: Optional[dtm.date] = None):
         """
-        지정된 기간 동안의 정규장 시작부터 현재 시각 (이전) 까지의 일봉 데이터를 조회합니다.  
+        지정된 기간 동안의 정규장 시작부터 현재 시각 (이전) 까지의 일봉 데이터를 조회합니다.
         단, market_nxt_on 이면, NXT 가능 종목의 경우 프리마켓, 정규마켓, 애프터마켓의 일봉을 모두 조회합니다.
         """
         today = self.clock.today()
@@ -758,9 +799,18 @@ class MockBroker(BaseBroker):
             dfs = get_us_daily_data([code], from_date, end_date, adjusted=True, ascending=True)
         else:
             if self.market_nxt_on:
-                dfs = get_kr_daily_data([code], from_date, end_date, adjusted=True, ascending=True, exchange=DataExchange.NXT)
-                if code not in dfs or dfs[code].empty:
-                    dfs = get_kr_daily_data([code], from_date, end_date, adjusted=True, ascending=True, exchange=DataExchange.KRX)
+                dfs = get_kr_daily_data([code], from_date, end_date, adjusted=True, ascending=True, exchange=DataExchange.KRX)
+                dfs_nxt = get_kr_daily_data([code], from_date, end_date, adjusted=True, ascending=True, exchange=DataExchange.NXT)
+                if code in dfs_nxt:
+                    _df = dfs[code]
+                    _df_nxt = dfs_nxt[code]
+
+                    # 같은 날짜의 데이터만 volume과 value를 합치고, open, close는 NXT 값으로 교체
+                    common_dates = _df.index.intersection(_df_nxt.index)
+                    for _date in common_dates:
+                        _df.loc[_date, 'volume'] = _df.loc[_date, 'volume'] + _df_nxt.loc[_date, 'volume']
+                        _df.loc[_date, 'value'] = _df.loc[_date, 'value'] + _df_nxt.loc[_date, 'value']
+                        _df.loc[_date, 'open'] = _df_nxt.loc[_date, 'open']
             else:
                 dfs = get_kr_daily_data([code], from_date, end_date, adjusted=True, ascending=True, exchange=DataExchange.KRX)
 
@@ -773,8 +823,13 @@ class MockBroker(BaseBroker):
             open_time = schedule.open_time
             close_time = schedule.close_time
             if self.market_nxt_on:
-                open_time = dtm.time(8, 0, 0)
-                close_time = dtm.time(20, 0, 0)
+                try:
+                    nxt_schedule = get_market_schedule(today, "NXT")
+                    open_time = nxt_schedule.open_time
+                    close_time = nxt_schedule.close_time
+                except ValueError:
+                    # 2025-03-04 이전 날짜는 ValueError 이므로 무시
+                    pass
 
             if schedule.full_day_closed:
                 pass  # end_date 가 폐장일이면 해당 날짜의 데이터는 이미 없음
@@ -933,18 +988,22 @@ class MockBroker(BaseBroker):
         self.get_positions()  # self.positions 에 있는 포지션들의 현재 가격을 조회하여 업데이트 함
 
         today = current_time.date()
-        market_schedule = get_market_schedule(today)
+        market_schedule = get_market_schedule(today, exchange=Exchange.KRX)
 
         open_time = dtm.datetime.combine(today, market_schedule.open_time)
         close_time = dtm.datetime.combine(today, market_schedule.close_time)
         preclose_auction_start_time = close_time - dtm.timedelta(minutes=10)
 
-        nxt_pre_open_time = dtm.datetime.combine(today, dtm.time(8, 0, 0))
-        nxt_pre_close_time = dtm.datetime.combine(today, dtm.time(8, 50, 0))
-        # nxt_main_open_time = dtm.datetime.combine(today, dtm.time(9, 0, 30))
-        # nxt_main_close_time = dtm.datetime.combine(today, dtm.time(15, 20, 0))
-        nxt_after_open_time = dtm.datetime.combine(today, dtm.time(15, 40, 0))
-        nxt_after_close_time = dtm.datetime.combine(today, dtm.time(20, 0, 0))
+        try:
+            nxt_market_schedule = get_market_schedule(today, exchange=Exchange.NXT)
+        except ValueError:
+            nxt_market_schedule = market_schedule
+        nxt_pre_open_time = dtm.datetime.combine(today, nxt_market_schedule.open_time)
+        nxt_pre_close_time = nxt_pre_open_time + dtm.timedelta(minutes=50)
+        # nxt_main_open_time = dtm.datetime.combine(today, open_time) + dtm.timedelta(seconds=30)
+        # nxt_main_close_time = close_time - dtm.timedelta(minutes=10)
+        nxt_after_open_time = close_time
+        nxt_after_close_time = dtm.datetime.combine(today, nxt_market_schedule.close_time)
 
         just_closed = current_time.replace(second=0, microsecond=0) == close_time.replace(second=0, microsecond=0)
         if preclose_auction_start_time - dtm.timedelta(minutes=1) <= current_time <= preclose_auction_start_time + dtm.timedelta(minutes=1):
@@ -971,6 +1030,10 @@ class MockBroker(BaseBroker):
                     # 강제로 1분 차이를 만들어 줌
                     before_time = current_time - dtm.timedelta(seconds=60)
 
+                if self.market_nxt_on and current_time < nxt_after_close_time and current_time - before_time < dtm.timedelta(seconds=60):
+                    # 강제로 1분 차이를 만들어 줌
+                    before_time = current_time - dtm.timedelta(seconds=60)
+
                 df = self.get_minute_price(order.asset_code)
                 if df.empty:
                     self.logger.warning(f"ORDER CANCELED: {order.asset_code} minute data is empty")
@@ -1278,6 +1341,7 @@ class MockBroker(BaseBroker):
                     d["market_cap"] = round(dft["value"].iloc[-1] / 100000000)
                 except Exception as e:
                     self.logger.error(f"get_market_cap error: {d['asset_code']} {d['name']} {prev_date} {e}")
+                    d["market_cap"] = 0
 
                 # 전일 거래대금
                 try:
@@ -1285,6 +1349,7 @@ class MockBroker(BaseBroker):
                     d["prev_value"] = round(dft["value"].iloc[-1] / 100000000)
                 except Exception as e:
                     self.logger.error(f"전일거래대금 error: {d['asset_code']} {d['name']} {prev_date} {e}")
+                    d["prev_value"] = 0
                 dict_list.append(d)
 
         df = pd.DataFrame(dict_list)
