@@ -1537,18 +1537,21 @@ class KISOverseasStock:
 
         return result
 
-    def inquire_ccnl(self,
-                     cano: str,
-                     acnt_prdt_cd: str,
-                     ord_strt_dt: dtm.date,
-                     ord_end_dt: dtm.date,
-                     ovrs_excg_cd: str,
-                     pdno: str = None,
-                     sll_buy_dvsn: str = "00",
-                     ccld_nccs_dvsn: str = "00",
-                     sort_sqn: str = "DS",
-                     ctx_area_fk200: str = "",
-                     ctx_area_nk200: str = ""):
+    def inquire_ccnl(
+        self,
+        cano: str,
+        acnt_prdt_cd: str,
+        ord_strt_dt: dtm.date,
+        ord_end_dt: dtm.date,
+        ovrs_excg_cd: str,
+        pdno: str = None,
+        sll_buy_dvsn: str = "00",
+        ccld_nccs_dvsn: str = "00",
+        sort_sqn: str = "DS",
+        ctx_area_fk200: str = "",
+        ctx_area_nk200: str = "",
+        tr_cont: str = "",
+    ):
         '''
         (해외주식주문) 해외주식 주문체결내역[v1_해외주식-007]
 
@@ -1632,8 +1635,7 @@ class KISOverseasStock:
             pdno = '' if self.auth.paper_trading else '%'
 
         path = '/uapi/overseas-stock/v1/trading/inquire-ccnl'
-        tr_id = 'VTTS3035R' if self.auth.paper_trading else 'TTTS3035R'
-        tr_cont = ''
+        tr_id = "VTTS3035R" if self.auth.paper_trading else "TTTS3035R"
         params = {
             'CANO': cano,
             'ACNT_PRDT_CD': acnt_prdt_cd,
@@ -1651,7 +1653,7 @@ class KISOverseasStock:
             'CTX_AREA_NK200': ctx_area_nk200,
         }
 
-        res_body, _ = self._tr_request(path, tr_id, tr_cont, params)
+        res_body, res_header = self._tr_request(path, tr_id, tr_cont, params)
         if res_body['rt_cd'] != '0':
             raise ValueError(f"Error: ({res_body['msg_cd']}) {res_body['msg1']}")
 
@@ -1673,12 +1675,13 @@ class KISOverseasStock:
             output.append(copied)
 
         result = {
-            'rt_cd': res_body['rt_cd'],
-            'msg_cd': res_body['msg_cd'],
-            'msg1': res_body['msg1'],
-            'ctx_area_fk200': res_body['ctx_area_fk200'],
-            'ctx_area_nk200': res_body['ctx_area_nk200'],
-            'output': output,
+            "rt_cd": res_body["rt_cd"],
+            "msg_cd": res_body["msg_cd"],
+            "msg1": res_body["msg1"],
+            "tr_cont": res_header["tr_cont"],
+            "ctx_area_fk200": res_body["ctx_area_fk200"],
+            "ctx_area_nk200": res_body["ctx_area_nk200"],
+            "output": output,
         }
 
         return result
