@@ -335,10 +335,15 @@ class KISSimpleDomesticStock:
         if schedule.full_day_closed:
             return _create_minute_dataframe()
 
-        # 만약 현재 시간이 거래소 마감 시간을 지났다면, 마감 시간으로 설정
+        # KRX 거래소에서 15:30 ~ 17:00 시간대에 API 호출하면 15:30분 데이터는 존재하지 않고, 해당 데이터가 호출시점(마지막) 인덱스에 존재 한다.
+        # 이러한 문제를 피하기위해 request_time을 장 종료 시간으로 설정한다.
+        requires_volume_correction = False
         if request_time.time() > schedule.close_time:
             request_time = request_datetime.replace(hour=schedule.close_time.hour, minute=schedule.close_time.minute)
 
+            if data_exchange == DataExchange.KRX:
+                requires_volume_correction = True
+
         while True:
             CallLimiter().wait_limit_rate(20, scope="kis/inquire_time_itemchartprice")
 
@@ -373,6 +378,13 @@ class KISSimpleDomesticStock:
             if request_time.time() < schedule.open_time:
                 break
 
+        # KRX 거래소에서 17시 이후에 API 호출하면 거래량이 2배로 보이는 문제가 있다. 장 마감 이후에는 거래량 검사를 진행한다.
+        if requires_volume_correction:
+            close = result[0].get("close")
+            volume = (result[0].get("cum_value") - result[1].get("cum_value")) / close
+            if volume != result[0].get("volume"):
+                result[0]["volume"] = int(volume)
+
         # 거래대금, 누적거래량 계산
         prev_cum_value = None
         prev_cum_volume = None
@@ -1066,7 +1078,7 @@ class KISSimpleDomesticStock:
         rejected = data.get("rfus_yn") == "1"
         rctf_cls = data.get("rctf_cls")  # 0: 신규, 1: 정정, 2: 취소
 
-        cancelled = rctf_cls == "2" and acpt_yn == "2" and cntg_yn == "1"
+        cancelled = rctf_cls == "2" and (acpt_yn == "2" or acpt_yn == "3") and cntg_yn == "1"
         updated = rctf_cls == "1" and acpt_yn == "2" and cntg_yn == "1"
         accepted = rctf_cls == "0" and acpt_yn == "1" and cntg_yn == "1"
         executed = cntg_yn == "2"
@@ -1107,7 +1119,8 @@ class KISSimpleDomesticStock:
         elif ord_exg_gb == "4":
             exchange = OrderExchange.SOR
 
-        print(f"- rctf_cls={rctf_cls} acpt_yn={acpt_yn} cntg_yn={cntg_yn} accepted={accepted} executed={executed} rejected={rejected} status={event_type}")
+        if account_no == f"{self.account_no}{self.account_product_code}":
+            print(f"- rctf_cls={rctf_cls} acpt_yn={acpt_yn} cntg_yn={cntg_yn} accepted={accepted} executed={executed} rejected={rejected} status={event_type}")
 
         return OrderEvent(
             asset_code,
