@@ -474,15 +474,7 @@ class TradingTracker:
         self.positions = self.simple_api.get_positions()
 
     def _refresh_pending_orders(self):
-        old_pending_orders = {}
-        for o in self.pending_orders:
-            old_pending_orders[o.order_no] = o
-
         self.pending_orders = self.simple_api.get_pending_orders(exchanges=list(OrderExchange))
-        for o in self.pending_orders:
-            old_pending_order = old_pending_orders.get(o.order_no)
-            if old_pending_order is not None:
-                o.average_purchase_price = old_pending_order.average_purchase_price
 
     def _notify_pending_order_update(self, status: str, order: StockOrder):
         # deprecated
