@@ -1,12 +1,16 @@
+import datetime as dtm
+from typing import List, Optional, Union
+
+import numpy as np
+import pandas as pd
+
+import pyqqq.config as c
+from pyqqq.datatypes import DataExchange
 from pyqqq.utils.api_client import raise_for_status, send_request
 from pyqqq.utils.array import chunk
+from pyqqq.utils.compute import get_krx_tick_size, quantize_adjusted_price
 from pyqqq.utils.local_cache import DiskCacheManager
 from pyqqq.utils.market_schedule import get_last_trading_day, get_market_schedule
-from typing import List, Optional, Union
-import datetime as dtm
-import pandas as pd
-import numpy as np
-import pyqqq.config as c
 
 domesticCache = DiskCacheManager("domestic_cache")
 
@@ -226,18 +230,29 @@ def _isoformat_to_readable(isodate: str) -> str:
 
 
 @domesticCache.memoize()
-def get_tickers(date: Optional[dtm.date] = None, market: Optional[str] = None):
+def get_tickers(
+    date: Optional[dtm.date] = None,
+    market: Optional[str] = None,
+    adjusted: Optional[bool] = True,
+    exchange: Union[str, DataExchange] = "KRX",
+):
     """
     주어진 날짜와 시장에 따른 주식 종목 코드와 관련 정보를 조회합니다.
 
     이 함수는 지정된 날짜(기본값은 오늘)와 선택적 시장('KOSPI', 'KOSDAQ')에 대한 주식 종목 코드와 추가 정보를 API를 통해 요청합니다.
     반환된 정보는 pandas DataFrame 형태로 제공되며, 데이터가 없는 경우 빈 DataFrame을 반환합니다. DataFrame은 'code'를 인덱스로 사용합니다.
 
-    2018년 1월 1일 데이터 부터 조회 가능합니다.
+    KRX 거래소에서는 거래정지 종목 등이 포함되어 있으나, NXT 거래소에서는 거래정지 종목이 제외되어 있습니다.
+
+    KRX 거래소는 2018년 1월 1일 데이터 부터 조회 가능합니다. 수정주가는 소수점 첫째 자리에서 반올림합니다.
+
+    NXT 거래소는 2025년 3월 4일 데이터 부터 조회 가능합니다. 수정주가는 소수점 첫째 자리에서 반올림합니다.
 
     Args:
         date (Optional[dtm.date]): 조회할 날짜. 기본값은 현재 날짜입니다.
-        market (Optional[str]): 조회할 시장. 'KOSPI' 또는 'KOSDAQ' 중 선택할 수 있습니다.
+        market (Optional[str]): 조회할 시장. 'KOSPI' 또는 'KOSDAQ' 중 선택할 수 있습니다. 기본값은 None 이며, 모든 시장을 조회합니다.
+        adjusted (Optional[bool]): 수정주가 여부. 기본값은 True.
+        exchange (Union[str, DataExchange]): 조회할 거래소. 'KRX' 또는 'NXT' 중 선택할 수 있습니다. 기본값은 'KRX' 입니다.
 
     Returns:
         pd.DataFrame: 주식 종목 코드와 관련 정보를 포함하는 DataFrame. 'code' 컬럼은 인덱스로 설정됩니다.
@@ -252,7 +267,7 @@ def get_tickers(date: Optional[dtm.date] = None, market: Optional[str] = None):
         - listing_date (str or None): 상장일
 
     Raises:
-        AssertionError: 잘못된 시장 이름이 입력된 경우 오류를 발생시킵니다.
+        AssertionError: 잘못된 시장이나 거래소 이름이 입력된 경우 오류를 발생시킵니다.
         HTTPError: API 요청이 실패했을 때 발생.
 
     Examples:
@@ -272,13 +287,23 @@ def get_tickers(date: Optional[dtm.date] = None, market: Optional[str] = None):
             "KOSDAQ",
         ], "market은 'KOSPI' 또는 'KOSDAQ'이어야 합니다."
 
+    assert exchange in [
+        "KRX", "NXT", DataExchange.KRX, DataExchange.NXT
+    ], "exchange는 'KRX' 또는 'NXT'이어야 합니다."
+
+    exchange = DataExchange.validate(exchange)
+
     if date is None:
         date = dtm.date.today()
         schedule = get_market_schedule(date)
         if schedule.full_day_closed:
             date = get_last_trading_day(date)
 
-    return _get_tickers(date, market)
+    # 2025년 3월 4일 이전 NXT 거래소 요청 시 빈 데이터 반환
+    if exchange == DataExchange.NXT and date < dtm.date(2025, 3, 4):
+        return pd.DataFrame()
+
+    return _get_tickers(date, market, adjusted, exchange)
 
 
 def _get_tickers_check_not_expected_res(res):
@@ -289,13 +314,17 @@ def _get_tickers_check_not_expected_res(res):
 
 
 @domesticCache.memoize(not_expected_res=_get_tickers_check_not_expected_res)
-def _get_tickers(date: dtm.date, market: str = None):
+def _get_tickers(date: dtm.date, market: str = None, adjusted: bool = True, exchange: DataExchange = DataExchange.KRX):
     """
     get_tickers 함수의 실제 구현부.
     기존 함수에선 date가 None이어도 정상적으로 돌아서 메모이제이션 하기 좋지않았음.
     """
     url = f"{c.PYQQQ_API_URL}/domestic-stock/tickers/{date.strftime('%Y%m%d')}"
-    params = {}
+    params = {
+        "adjusted": "true" if adjusted else "false",
+        "current_date": dtm.date.today(),
+        "exchange": exchange.value,
+    }
     if market:
         params["market"] = market
 
@@ -311,6 +340,49 @@ def _get_tickers(date: dtm.date, market: str = None):
 
     df = pd.DataFrame(rows, columns=cols)
     df.set_index("code", inplace=True)
+
+    if adjusted:
+        for col in ["reference_price", "upper_limit", "lower_limit", "previous_close"]:
+            if col in df.columns:
+                df[col] = df[col].apply(lambda x: quantize_adjusted_price(x) if pd.notna(x) else x)
+
+    # None 값 처리: upper_limit, lower_limit, previous_close
+    mask_upper_limit = df["upper_limit"].isna()
+    mask_lower_limit = df["lower_limit"].isna()
+    mask_previous_close = df["previous_close"].isna()
+
+    # reference_price 기준으로 상한가/하한가 계산
+    if "reference_price" in df.columns:
+        # 상한가/하한가 계산 함수
+        def calculate_price_limit(row):
+            price = row["reference_price"]
+            market = row["market"]
+            etf_etn = row["type"] == "ETF" or row["type"] == "ETN"
+
+            tick_size = get_krx_tick_size(price, etf_etn, market, date)
+
+            # 상한가 계산 (1.3배) 후 호가단위로 절삭 (내림)
+            upper = price * 1.3
+            upper = int(upper // tick_size * tick_size)
+
+            # 하한가 계산 (0.7배) 후 호가단위로 절삭 (올림)
+            lower = price * 0.7
+            lower = int((lower + tick_size - 0.01) // tick_size * tick_size)
+
+            return pd.Series([upper, lower])
+
+        # 상한가/하한가 계산 적용
+        if mask_upper_limit.any() or mask_lower_limit.any():
+            limits = df.loc[mask_upper_limit | mask_lower_limit].apply(calculate_price_limit, axis=1)
+            if not limits.empty:
+                df.loc[mask_upper_limit, "upper_limit"] = limits[0]
+                df.loc[mask_lower_limit, "lower_limit"] = limits[1]
+
+        # previous_close 채우기
+        df.loc[mask_previous_close, "previous_close"] = df.loc[mask_previous_close, "reference_price"]
+
+    df = df.astype({"reference_price": int, "upper_limit": int, "lower_limit": int, "previous_close": int})
+
     return df
 
 
