@@ -14,7 +14,7 @@ import os
 import traceback
 import dotenv
 
-logger = get_logger("executor")
+logger = get_logger(__name__)
 
 
 class HookExecutor:
